<?php
/**
*** @name: display.php
***
*** @description: controller for common display ajax requests
*** @author: Quentin George <q.george@esia-sa.com>
*** @date: 27/04/2023
**/

$path = $_SERVER['DOCUMENT_ROOT'];
include_once $path . '/common.php';

// Action
if(isset($_GET['action']))
{
	$action = $_GET['action'];
}
elseif(isset($_POST['action']))
{
	$action = $_POST['action'];
}

try
{
	if($action == 'changeLang')
	{
		$ret = '';
		if(isset($_POST['lang']))
		{
			session_start();
			$_SESSION['user_conf']['lang'] = $_POST['lang'];
			session_write_close();
			$ret = $_POST['lang'];
		}

		echo json_encode($ret);
		exit(0);
	}
	elseif($action == 'updateUsers')
	{
		// Check parameters
		// Current password
		$oldPasswd = '';
		if(isset($_POST['oldPasswd']))
		{
			$oldPasswd = trim($_POST['oldPasswd']);
		}
		if(strlen($oldPasswd) == 0)
		{
			throw new Exception($lang['ERR_CURRENT_PASSWD_REQUIRED']);
		}
		// New password
		$newPasswd = '';
		$confirmPasswd = '';
		if(isset($_POST['newPasswd']) && isset($_POST['confirmPasswd']))
		{
			$newPasswd = trim($_POST['newPasswd']);
			$confirmPasswd = trim($_POST['confirmPasswd']);
		}
		if(strlen($newPasswd) == 0 || $newPasswd != $confirmPasswd)
		{
			throw new Exception($lang['ERR_PASSWD_NOT_CONFIRMED']);
		}

		// User lang for current session
		if(isset($_POST['userLang']))
		{
			session_start();
			$_SESSION['user_conf']['lang'] = $_POST['userLang'];
			session_write_close();

			// Save inside data file
			$userConf = getJsonConfFile($path . DATA_DIR . USER_CONF_FILE);
			$userConf['lang'] = $_POST['userLang'];
			$isWritten = setJsonConfFile($path . DATA_DIR . USER_CONF_FILE, $userConf);
			if($isWritten == FALSE)
			{
				throw new Exception($lang['ERR_SAVE_USER_LANG']);
			}
		}

		// Update linux user passwd
		$cmd = 'sudo ' . SHELL_SCRIPTS . 'userpass.sh ' . escapeshellarg($oldPasswd) . ' ' . escapeshellarg($newPasswd);
		exec($cmd, $output, $code);
		handleExecError($code, $output);

		// Update lang for message
		$lang = array();
		$lang_path = $path . 'lang/' . $userConf['lang'] . '/'. $userConf['lang'] . '.php';
		if(file_exists($lang_path))
		{
			include $lang_path;
		}

		echo json_encode($lang['PARAMS_UPDATE_SUCCESS']);
		exit(0);
	}
	elseif($action == 'getGesaUpdateLog')
	{
		// Check last update time
		$updates = getGesaLastUpdate();
		// Get logs
		$updates['log'] = getFileLastLine(GESA_LOGS_FILE);
		
		echo json_encode($updates);
		exit(0);
	}
	elseif($action == 'updateGesa')
	{
		if(!file_exists(GESA_UPDATES_SCRIPT_FILE))
		{
			throw new Exception($lang['MISSING_FILE'] . '(' . GESA_UPDATES_SCRIPT_FILE . ')');
		}
		// Update
		execWithLiveReturn('sudo ' . GESA_UPDATES_SCRIPT_FILE);
		exit(0);
	}
	elseif($action == 'updateIface')
	{
		if(empty($_POST['index']))
		{
			throw new Exception($lang['ERR_MISSING_IFACE_DATA']);
		}

		// Get ifaces conf file data
		$netConfFilePath = $path . DATA_DIR . NETWORK_CONF_FILE;
		$netConf = getJsonConfFile($netConfFilePath);

		// Format data
		$ifInfo = explode('-', $_POST['index']);
		$iface = array(
			'index' => intval($ifInfo[0]),
			'name' => $ifInfo[1],
			'mac' => $ifInfo[2],
			'label' => $_POST['label'],
			'type' => $_POST['type'],
			'vlan' => 0,
			'dhcp' => FALSE,
			'ip_addr' => $_POST['ip_addr'],
			'netmask' => $_POST['netmask'],
			'gateway' => $_POST['gateway'],
			'dns' => preg_split('/,\s*/', trim($_POST['dns'])),
		);

		// If it's main MGMT interface
		if($_POST['jsonKey'] == 'mgmt')
		{
			$taggedIndex = 'mgmt';

			$iface['label'] = 'MGMT';
			$iface['type'] = 'MGMT';
		}
		else
		{
			$taggedIndex = $iface['index'];
			if(isset($_POST['is_vlan']) && is_numeric($_POST['vlan']))
			{
				$iface['vlan'] = intval($_POST['vlan']);
				$taggedIndex = $iface['index'] . '.' . $iface['vlan'];
			}
		}

		// Is DHCP
		if(isset($_POST['is_dhcp']))
		{
			$iface['dhcp'] = TRUE;
		}

		// Check if the index is used by another iface conf. Only if the index has change or it's a new interface
		if($taggedIndex != $_POST['jsonKey'])
		{
			// Get iface conf file list
			$ifaces = array_keys($netConf);
			// Get main mgmt index if not present in conf file
			$ifsArray = shell_exec('ip -a -j addr');
			if(!empty($ifsArray))
			{
				$ifsArray = json_decode($ifsArray, TRUE);
				// $ifsArray[0] is the loopback, $ifsArray[1] is the main mgmt
				$ifaces[] = $ifsArray[1]['ifindex'];
			}
			// Throw exception if the index is found
			if(in_array($taggedIndex, $ifaces))
			{
				throw new Exception($lang['ERR_SAVE_IFACE_DUPLICATION_INDEX']);
			}
		}

		// Format data
		// Remove old key if vlan changed
		unset($netConf[$_POST['jsonKey']]);
		$netConf[$taggedIndex] = $iface;
		// Save inside data file
		$isWritten = setJsonConfFile($netConfFilePath, $netConf);
		if($isWritten == FALSE)
		{
			throw new Exception($lang['ERR_SAVE_IFACE_DATA']);
		}

		// Handling response message. If not mgmt interface or no index key this is a new interface
		if($taggedIndex == 'mgmt' || $_POST['jsonKey'] != 0)
		{
			$response = array(
				'type' => 'update',
				'success' => $lang['PARAMS_IFACE_UPDATE_SUCCESS'],
			);
		}
		else
		{
			$response = array(
				'type' => 'add',
				'success' => $lang['PARAMS_IFACE_ADD_SUCCESS'],
			);
		}
		
		echo json_encode($response);
		exit(0);
	}
	elseif($action == 'netconfigure')
	{
		$netConfFilePath = $path . DATA_DIR . NETWORK_CONF_FILE;
		exec('sudo ' . NET_CONF_SCRIPT_PATH . ' -f ' . $netConfFilePath, $output, $code);
		handleExecError($code, $output);

		echo json_encode('');
		exit(0);
	}
	elseif($action == 'addProtocolConfFile')
	{
		if(empty($_POST['tab']))
		{
			throw new Exception($lang['ERR_PROT_TYPE_MISSING']);
		}
		if(empty($_POST['fileName']))
		{
			throw new Exception($lang['ERR_PROT_FILENAME_MISSING']);
		}
		
		if($_POST['tab'] == 'ssh')
		{
			$fileName = $_POST['fileName'] . '.ssh.conf';
			if(file_exists(PLUGINS_CONF_FILES_DIR . $fileName))
			{
				throw new Exception($lang['ERR_PROT_FILENAME_EXISTS'] . ' (' . $fileName . ')');
			}
			$conf = array(
                'host' => $_POST['host'],
                'port' => $_POST['port'],
                'user' => $_POST['user'],
                'password' => $_POST['password'],
            );

			// Save inside data file
			$isWritten = setJsonConfFile(PLUGINS_CONF_FILES_DIR . $fileName, $conf);
			if($isWritten == FALSE)
			{
				throw new Exception($lang['ERR_CANNOT_SAVE_FILE'] . ': ' . PLUGINS_CONF_FILES_DIR . $fileName);
			}
		}
		elseif($_POST['tab'] == 'powershell')
        {
            $fileName = $_POST['fileName'] . '.pwsh.conf';
			if(file_exists(PLUGINS_CONF_FILES_DIR . $fileName))
			{
				throw new Exception($lang['ERR_PROT_FILENAME_EXISTS'] . ' (' . $fileName . ')');
			}
			$conf = array(
                'host' => $_POST['host'],
                'user' => $_POST['user'],
                'password' => $_POST['password'],
            );

			// Save inside data file
			$isWritten = setJsonConfFile(PLUGINS_CONF_FILES_DIR . $fileName, $conf);
			if($isWritten == FALSE)
			{
				throw new Exception($lang['ERR_CANNOT_SAVE_FILE'] . ': ' . PLUGINS_CONF_FILES_DIR . $fileName);
			}
        }
        elseif($_POST['tab'] == 'ipmi')
        {
            $fileName = $_POST['fileName'] . '.ipmi.conf';
			if(file_exists(PLUGINS_CONF_FILES_DIR . $fileName))
			{
				throw new Exception($lang['ERR_PROT_FILENAME_EXISTS'] . ' (' . $fileName . ')');
			}
			// Check validity privilege & driver
			if(!in_array($_POST['privilege'], PROTOCOLS_CONF_AVAILABLE['ipmi']['privileges']))
			{
				throw new Exception($lang['ERR_UNKNOWN__PRIVILEGE']);
			}
			if(!in_array($_POST['driver'], PROTOCOLS_CONF_AVAILABLE['ipmi']['versions']))
			{
				throw new Exception($lang['ERR_UNKNOWN__DRIVER']);
			}

			$conf = array(
                'username' => $_POST['user'],
                'password' => $_POST['password'],
				'privilege-level' => $_POST['privilege'],
                'driver-type' => $_POST['driver'],
            );

			// Save inside data file
			$isWritten = setTxtConfFile(PLUGINS_CONF_FILES_DIR . $fileName, $conf, ' ');
			if($isWritten == FALSE)
			{
				throw new Exception($lang['ERR_CANNOT_SAVE_FILE'] . ': ' . PLUGINS_CONF_FILES_DIR . $fileName);
			}
        }
		elseif($_POST['tab'] == 'virt')
        {
			if(!$gesa->getIsVM())
			{
				throw new Exception($lang['NO_ACCESS']);
			}

            $fileName = $_POST['fileName'] . '.virt.conf';
			if(file_exists(PLUGINS_CONF_FILES_DIR . $fileName))
			{
				throw new Exception($lang['ERR_PROT_FILENAME_EXISTS'] . ' (' . $fileName . ')');
			}
			$conf = array(
                'login' => $_POST['login'],
                'password' => $_POST['password'],
            );

			// Save inside data file
			$isWritten = setJsonConfFile(PLUGINS_CONF_FILES_DIR . $fileName, $conf);
			if($isWritten == FALSE)
			{
				throw new Exception($lang['ERR_CANNOT_SAVE_FILE'] . ': ' . PLUGINS_CONF_FILES_DIR . $fileName);
			}
        }
		elseif($_POST['tab'] == 'backup')
        {
			if(!$gesa->getIsVM())
			{
				throw new Exception($lang['NO_ACCESS']);
			}

            if(empty($_POST['subtab']))
			{
				throw new Exception($lang['ERR_BCK_DRIVER_NOT_FOUND']);
			}

			$subtab = $_POST['subtab'];
			$fileName = $_POST['fileName'] . '.' . $subtab . '.bck.conf';
			if(file_exists(PLUGINS_CONF_FILES_DIR . $fileName))
			{
				throw new Exception($lang['ERR_PROT_FILENAME_EXISTS'] . ' (' . $fileName . ')');
			}

			// Parameter config by subtab (driver)
			$conf = array();
			if($subtab == 'appassure')
			{
				if(empty($_POST['port']) || $_POST['port'] < 0 || $_POST['port'] > 65535)
				{
					$_POST['port'] = 0;
				}

				$conf = array(
					'community' => $_POST['community'],
					'port' => $_POST['port'],
				);
			}
			elseif($subtab == 'bareos')
			{
				$conf = array(
					'pass' => $_POST['pass'],
				);
			}
			elseif($subtab == 'proxmox')
			{
				$conf = array(
					'url' => $_POST['url'],
					'username' => $_POST['username'],
					'token_name' => $_POST['token_name'],
					'token_value' => $_POST['token_value'],
				);
			}
			elseif($subtab == 'veeam')
			{
				if(empty($_POST['port']) || $_POST['port'] < 0 || $_POST['port'] > 65535)
				{
					$_POST['port'] = 0;
				}

				$conf = array(
					'dbdriver' => 'pgsql',
					'port' => $_POST['port'],
					'dbname' => $_POST['dbname'],
					'dbuser' => $_POST['dbuser'],
					'dbpass' => $_POST['dbpass'],
				);
			}
			elseif($subtab == 'veeam365')
			{
				$conf = array(
					'url' => $_POST['url'],
					'proxyserver' => $_POST['proxyserver'],
					'username' => $_POST['username'],
					'password' => $_POST['password'],
				);
			}
			else
			{
				throw new Exception($lang['ERR_BCK_DRIVER_NOT_FOUND'] . ' (' . $subtab . ')');
			}

			// Save inside data file
			$isWritten = setJsonConfFile(PLUGINS_CONF_FILES_DIR . $fileName, $conf);
			if($isWritten == FALSE)
			{
				throw new Exception($lang['ERR_CANNOT_SAVE_FILE'] . ': ' . PLUGINS_CONF_FILES_DIR . $fileName);
			}
        }
		else
		{
			throw new Exception($lang['ERR_PROT_WRONG_TYPE']);
		}

		echo json_encode('');
		exit(0);
	}
	elseif($action == 'updProtocolConfFile')
	{
		if(empty($_POST['tab']))
		{
			throw new Exception($lang['ERR_PROT_TYPE_MISSING']);
		}
		if(empty($_POST['fileName']))
		{
			throw new Exception($lang['ERR_PROT_FILENAME_MISSING']);
		}
		
		if($_POST['tab'] == 'ssh')
		{
			$conf = array(
                'host' => $_POST['host'],
                'port' => $_POST['port'],
                'user' => $_POST['user'],
                'password' => $_POST['password'],
            );

			// Save inside data file
			$isWritten = setJsonConfFile(PLUGINS_CONF_FILES_DIR . $_POST['fileName'], $conf);
			if($isWritten == FALSE)
			{
				throw new Exception($lang['ERR_CANNOT_SAVE_FILE'] . ': ' . PLUGINS_CONF_FILES_DIR . $_POST['fileName']);
			}
		}
		elseif($_POST['tab'] == 'powershell')
        {
            $conf = array(
                'host' => $_POST['host'],
                'user' => $_POST['user'],
                'password' => $_POST['password'],
            );

			// Save inside data file
			$isWritten = setJsonConfFile(PLUGINS_CONF_FILES_DIR . $_POST['fileName'], $conf);
			if($isWritten == FALSE)
			{
				throw new Exception($lang['ERR_CANNOT_SAVE_FILE'] . ': ' . PLUGINS_CONF_FILES_DIR . $_POST['fileName']);
			}
        }
        elseif($_POST['tab'] == 'ipmi')
        {
			// Check validity privilege & driver
			if(!in_array($_POST['privilege'], PROTOCOLS_CONF_AVAILABLE['ipmi']['privileges']))
			{
				throw new Exception($lang['ERR_UNKNOWN__PRIVILEGE']);
			}
			if(!in_array($_POST['driver'], PROTOCOLS_CONF_AVAILABLE['ipmi']['versions']))
			{
				throw new Exception($lang['ERR_UNKNOWN__DRIVER']);
			}
			
			$conf = array(
                'username' => $_POST['user'],
                'password' => $_POST['password'],
				'privilege-level' => $_POST['privilege'],
                'driver-type' => $_POST['driver'],
            );

			// Save inside data file
			$isWritten = setTxtConfFile(PLUGINS_CONF_FILES_DIR . $_POST['fileName'], $conf, ' ');
			if($isWritten == FALSE)
			{
				throw new Exception($lang['ERR_CANNOT_SAVE_FILE'] . ': ' . PLUGINS_CONF_FILES_DIR . $_POST['fileName']);
			}
        }
		elseif($_POST['tab'] == 'virt')
        {
			if(!$gesa->getIsVM())
			{
				throw new Exception($lang['NO_ACCESS']);
			}

            $conf = array(
                'login' => $_POST['login'],
                'password' => $_POST['password'],
            );

			// Save inside data file
			$isWritten = setJsonConfFile(PLUGINS_CONF_FILES_DIR . $_POST['fileName'], $conf);
			if($isWritten == FALSE)
			{
				throw new Exception($lang['ERR_CANNOT_SAVE_FILE'] . ': ' . PLUGINS_CONF_FILES_DIR . $_POST['fileName']);
			}
        }
		elseif($_POST['tab'] == 'backup')
        {
			if(!$gesa->getIsVM())
			{
				throw new Exception($lang['NO_ACCESS']);
			}

            if(empty($_POST['subtab']))
			{
				throw new Exception($lang['ERR_BCK_DRIVER_NOT_FOUND']);
			}
			$subtab = $_POST['subtab'];

			// Parameter config by subtab (driver)
			$conf = array();
			if($subtab == 'appassure')
			{
				if(empty($_POST['port']) || $_POST['port'] < 0 || $_POST['port'] > 65535)
				{
					$_POST['port'] = 0;
				}

				$conf = array(
					'community' => $_POST['community'],
					'port' => $_POST['port'],
				);
			}
			elseif($subtab == 'bareos')
			{
				$conf = array(
					'pass' => $_POST['pass'],
				);
			}
			elseif($subtab == 'proxmox')
			{
				$conf = array(
					'url' => $_POST['url'],
					'username' => $_POST['username'],
					'token_name' => $_POST['token_name'],
					'token_value' => $_POST['token_value'],
				);
			}
			elseif($subtab == 'veeam')
			{
				if(empty($_POST['port']) || $_POST['port'] < 0 || $_POST['port'] > 65535)
				{
					$_POST['port'] = 0;
				}

				$conf = array(
					'dbdriver' => 'pgsql',
					'port' => $_POST['port'],
					'dbname' => $_POST['dbname'],
					'dbuser' => $_POST['dbuser'],
					'dbpass' => $_POST['dbpass'],
				);
			}
			elseif($subtab == 'veeam365')
			{
				$conf = array(
					'url' => $_POST['url'],
					'proxyserver' => $_POST['proxyserver'],
					'username' => $_POST['username'],
					'password' => $_POST['password'],
				);
			}
			else
			{
				throw new Exception($lang['ERR_BCK_DRIVER_NOT_FOUND'] . ' (' . $subtab . ')');
			}

			// Save inside data file
			$isWritten = setJsonConfFile(PLUGINS_CONF_FILES_DIR . $_POST['fileName'], $conf);
			if($isWritten == FALSE)
			{
				throw new Exception($lang['ERR_CANNOT_SAVE_FILE'] . ': ' . PLUGINS_CONF_FILES_DIR . $_POST['fileName']);
			}
        }
		else
		{
			throw new Exception($lang['ERR_PROT_WRONG_TYPE']);
		}

		echo json_encode('');
		exit(0);
	}
	elseif($action == 'delProtocolConfFile')
	{
		if(empty($_POST['fileName']))
		{
			throw new Exception($lang['ERR_PROT_FILENAME_MISSING']);
		}
		if(in_array($_POST['fileName'], DEFAULT_PROTOCOLS_CONF_FILES))
		{
			throw new Exception($lang['ERR_CANNOT_DELETE_DEFAULT_FILE']);
		}
		
		$isDel = unlink(PLUGINS_CONF_FILES_DIR . $_POST['fileName']);
		if($isDel == FALSE)
		{
			throw new Exception($lang['ERR_CANNOT_DELETE_FILE'] . ': ' . PLUGINS_CONF_FILES_DIR . $_POST['fileName']);
		}

		echo json_encode('');
		exit(0);
	}
	elseif($action == 'getGesaIpPub')
	{
		// Get network data
		$ipPub = '';
		$ret = shell_exec('dig +short +tries=3 +time=1 myip.opendns.com @resolver1.opendns.com');
		if(!empty($ret))
		{
			$ret = trim($ret);
			if(filter_var($ret, FILTER_VALIDATE_IP))
			{
				$ipPub = $ret;
			}
		}

		echo json_encode($ipPub);
		exit(0);
	}
	elseif($action == 'getGesaServerInfos')
	{
		// Get server url & port
		$server = array(
			'url' => '',
			'port' => '',
		);

		// Check ectp conf file /etc/gesa/ecatp.conf
		$gesaServerUrl = getEcatpConfFileValue('SERVER_URL');
		$gesaServerUrl = ltrim($gesaServerUrl, 'wss://');

		// If empty after trim
		if(empty($gesaServerUrl))
		{
			// Check in file created by the cloud_url cron task /var/log/gesa_server_url
			$gesaServerUrl = file_get_contents(SERVER_URL_FILE);
			if(!empty($gesaServerUrl))
			{
				$gesaServerUrl = trim($gesaServerUrl);
			}
			// If empty after trim. Not found in file, try to contact info gesa with gesa serial number
			if(empty($gesaServerUrl) && !empty($_POST['gesa_sn']))
			{
				$streamContext = stream_context_create(array(
					'http' => array(
						'timeout' => REQUESTS_TIMEOUT, // Timeout for php http requests
					),
				));
				$url = INFO_GESA_PROTOCOL . INFO_GESA_URL . '/api_gesa.php?action=info&SN=' . $_POST['gesa_sn'];
				// Use file_get_contents before simplexml_load to use with stream_context for timeout on web request
				$xml = file_get_contents($url, FALSE, $streamContext);
				if(!empty($xml))
				{
					$xml = simplexml_load_string($xml);
					if(!empty($xml->server_url))
					{
						$gesaServerUrl = trim($xml->server_url);
					}
				}
			}
		}
		
		// After all url fetch tries, if an url has been found, extract url & port
		if(!empty($gesaServerUrl))
		{
			// Split port
			$arr = preg_split("/:([0-9]+)$/", $gesaServerUrl, 0, PREG_SPLIT_DELIM_CAPTURE);
			$server['url'] = $arr[0];
			if(!empty($arr[1]))
			{
				$server['port'] = $arr[1];
			}
			else
			{
				// Default port for infogesa is 443 if not specified in URL
				$server['port'] = 443;
				if(strEndsWith($server['url'], '/ws'))
				{
					// It's a web socket, remove it from url and port is 443 (esia proxy will redirect it to 2080 in Esia LAN network)
					$server['url'] = rtrim($server['url'], '/ws');
				}
			}
		}

		echo json_encode($server);
		exit(0);
	}
	elseif($action == 'getGesaDiagDNS')
	{
		// Get diag DNS
		$isDNS = FALSE;

		exec('nslookup ' . INFO_GESA_URL, $output, $code);
		if($code == 0)
		{
			$isDNS = TRUE;
		}

		echo json_encode($isDNS);
		exit(0);
	}
	elseif($action == 'getGesaDiagWEB')
	{
		// Get diag WEB access
		$isWEB = FALSE;

		$streamContext = stream_context_create(array(
			'http' => array(
				'timeout' => REQUESTS_TIMEOUT, // Timeout for php http requests
			),
		));
		if(!empty(@get_headers(DIAG_WEB_URL, FALSE, $streamContext)))
		{
			$isWEB = TRUE;
		}

		echo json_encode($isWEB);
		exit(0);
	}
	elseif($action == 'getGesaDiagSRV')
	{
		// Get diag server connection
		$isSRV = FALSE;

		// Check server access
		if(!empty($_POST['server_url']) && !empty($_POST['port']) && file_exists(GESA_PLUGINS . 'check_tcp'))
		{
			// Use check_tcp on url & port to verify server access
			$ret = shell_exec(GESA_PLUGINS . 'check_tcp -H ' . $_POST['server_url'] . ' -p ' . $_POST['port'] . ' -t ' . REQUESTS_TIMEOUT);
			if(!empty($ret) && preg_match('/^TCP\sOK/', trim($ret)))
			{
				$isSRV = TRUE;
			}
		}

		echo json_encode($isSRV);
		exit(0);
	}
	elseif($action == 'getGesaDiagECATP')
	{
		// Get diag ECATP
		$isECATP = FALSE;

		// Check ECATP service status
		exec('service ecatp-client status | grep "active (running)"', $output, $code);
		if($code == 0)
		{
			// Service is running, check ECATP log file for more informations
			// Get log info file path from ecatp.conf
			$logInfoPath = getEcatpConfFileValue('LOG_INFO');
			$isECATP = getECATPStateFromLog($logInfoPath);
		}

		echo json_encode($isECATP);
		exit(0);
	}
}
catch(Exception $e)
{
	echo json_encode(array('error' => $e->getMessage()));
}

// Get the ECATP client status connected or not with retries if pending (STARTING, CONNECTING, REGISTERING)
// $logInfos results :
// 'STATUS' == 'STARTING' (The program start & try to connect to infogesa.esia-sa.com)
// 'STATUS' == 'CONNECTING' (Receiving ECATP server connection data)
// 'STATUS' == 'REGISTERING' (ECATP server registering attempt)
// 'STATUS' == 'RUNNING' (Registered & connected)
// 'REGISTER' == 'NONE' (Not registered [yet])
// 'REGISTER' == 'OK' (Registered)
function getECATPStateFromLog($logInfoPath)
{
	$isConnected = FALSE;

	if(file_exists($logInfoPath))
	{
		$maxRetries = 3; // STARTING then CONNECTING then REGISTERING then RUNNING
		$retryCount = 0;
		$prevStatus = '';

		// Get data recursively until the connection is OK or the maxRetries has been reached (Stop if the status does not change between two tries)
		do
		{
			// If not first try, wait a bit before the retry
			if($retryCount > 0)
			{
				sleep(REQUESTS_TIMEOUT);
			}

			// Get log infos from configured log file in ecatp.conf
			$logInfos = parse_ini_file($logInfoPath, FALSE, INI_SCANNER_RAW);

			// Format status
			if(isset($logInfos['STATUS']) && isset($logInfos['REGISTER']))
			{
				if($logInfos['STATUS'] == 'RUNNING' && $logInfos['REGISTER'] == 'OK')
				{
					$isConnected = TRUE;
					break;
				}
				elseif($prevStatus == $logInfos['STATUS'])
				{
					// Status has not change between two tries, abort
					break;
				}
				else
				{
					// Save status for next try
					$prevStatus = $logInfos['STATUS'];
				}
			}

			$retryCount++;
		}
		while($retryCount <= $maxRetries);
	}

    return $isConnected;
}

exit(0);

?>
