<?php
/**
*** @name GesaInterface.class.php
*** @description Main Gesa class for gesa web interface
*** @author Quentin George <q.george@esia-sa.com>
*** @version 1.0.0
*** @date 24/04/2023
**/

class GesaInterface
{
	const GESA_MIN_SN_COUNT = 11;
	const GESA_MAX_SN_COUNT = 13;

	protected $port;
	protected $sn;
	protected $maxSlot;
	protected $version_base;
	protected $version_plugin;
	protected $version_web;
	protected $repo_global;
	protected $repo_gesa;
	protected $last_update;
	protected $model;
	protected $localip;
	protected $publicip;
	protected $netmask;
	protected $gateway;
	protected $dns;
	protected $server_url;
	protected $interfaces;
	protected $type;
	protected $isVM;
	protected $version_os;
	/*@NAME: __construct
	 *@IN: /
	*@OUT: /
	*@TREAT: constructeur de base
	*@EXCEPTION: /
	*/
	public function __construct ()
	{
		$this->port = NULL;
		$this->sn = NULL;
		$this->maxSlot = 30;
		$this->model = '';
		$this->localip = '';
		$this->publicip = '';
		$this->netmask = '';
		$this->gateway = '';
		$this->dns = array();
		$this->server_url = '';
		$this->interfaces = array();
		$this->type = '';
		$this->isVM = FALSE;
		$this->version_os = '';
	}
	/**
	***
	*** @NAME: toArray
	*** @DESC: return all class vars and methods results as an array
	*** @IN: /
	*** @OUT: array all methods converted to array
	*** @THROW: /
	**/
	public function toArray()
	{
		return array(
			'port' => $this->port,
			'sn' => $this->sn,
			'maxSlot' => $this->maxSlot,
			'version_base' => $this->version_base,
			'version_plugin' => $this->version_plugin,
			'version_web' => $this->version_web,
			'repo_global' => $this->repo_global,
			'repo_gesa' => $this->repo_gesa,
			'last_update' => $this->last_update,
			'model' => $this->model,
			'localip' => $this->localip,
			'publicip' => $this->publicip,
			'netmask' => $this->netmask,
			'gateway' => $this->gateway,
			'dns' => $this->dns,
			'server_url' => $this->server_url,
			'interfaces' => $this->interfaces,
			'type' => $this->type,
			'isVM' => $this->isVM,
			'version_os' => $this->version_os,
		);
	}
	/*@NAME: setSerialNumber
	 *@IN: le numeros de serie
	*@OUT: /
	*@TREAT: set le numeos de serie
	*@EXCEPTION:
	*/
	public function setSerialNumber($serial)
	{
		// If there is - in the SN remove them to get an integer
		$serial = intval(str_replace('-', '', $serial));
		// Serial number can be between 11 & 13 chars length
		if(strlen($serial) >= self::GESA_MIN_SN_COUNT && strlen($serial) <= self::GESA_MAX_SN_COUNT)
		{
			$this->sn = $serial;
		}
		else
		{
			throw new GesaException('Wrong serial number format');
		}
	}
	/*@NAME: getSerialNumber
	 *@IN: /
	*@OUT:  le numÃ©ros de sÃ©rie ou null s'il n'y en a pas
	*@TREAT: formate le numÃ©ros de sÃ©rie et le renvoie
	*@EXCEPTION:
	*/
	public function getSerialNumber()
	{
		return $this->sn;
	}
	/**
	***
	*** @NAME: setType
	*** @DESC: Set gesa type (unity, ...)
	*** @IN: (STRING) $type => le type de la gesa
	*** @OUT: /
	*** @THROW: /
	**/
	public function setType($type)
	{
		$this->type = $type;
	}
	/*@NAME:getType
	 *@IN: /
	*@OUT: le type de la gesa
	*@TREAT: retourne le type
	*@EXCEPTION: 	/
	*/
	public function getType()
	{
		return $this->type;
	}
	/**
	***
	*** @NAME: setIsVM
	*** @DESC: Set gesa vm or not
	*** @IN: (BOOLEAN) $bool => TRUE if the gesa is Virtualized
	*** @OUT: /
	*** @THROW: /
	**/
	public function setIsVM($bool)
	{
		if($bool == TRUE)
		{
			$this->isVM = TRUE;
		}
		else
		{
			$this->isVM = FALSE;
		}
	}
	/**
	***
	*** @NAME: getIsVM
	*** @DESC: Return true if the gesa is virtualized
	*** @IN: /
	*** @OUT: Boolean isVM
	*** @THROW: /
	**/
	public function getIsVM()
	{
		return $this->isVM;
	}
	/*@NAME: getMaxSlot
	 *@IN: /
	*@OUT:  Nombre maximun de slot 5 min disponible
	*@TREAT: retourne le nombre maximun de slot
	*@EXCEPTION:
	*/
	public function getMaxSlot()
	{
		return $this->maxSlot;
	}
	/*@NAME: setMaxSlot
	 *@IN:  $max = Nombre maximun de slot 5 min disponible
	*@OUT:  /
	*@TREAT: set le nombre maximun de slot
	*@EXCEPTION:
	*/
	public function setMaxSlot($max)
	{
		$this->maxSlot= $max;
	}

	/**
	 * retourne le port utilisé par la GESA
	 * @return number
	 */
	public function getPort()
	{
		return $this->port;
	}
	/**
	 * set le port TCP de la GESA
	 * @param integer $port
	 */
	public function setPort($port)
	{
		$this->port= $port;
	}
	/**
	 * retourne la version de l'OS
	 * @return string version du paquet
	 */
	public function getVersionOS()
	{
		return $this->version_os;
	}
	/**
	 * set la version de l'OS
	 * @param string $version
	 */
	public function setVersionOS($version)
	{
		$this->version_os = $version;
	}
	/**
	 * retourne la version du paque gesa-base
	 * @return string version du paquet
	 */
	public function getVersionBase()
	{
		return $this->version_base;
	}
	/**
	 * set la version du paquet gesa-base
	 * @param string $version
	 */
	public function setVersionBase($version)
	{
		$this->version_base= $version;
	}
	/**
	 * retourne la version du paque gesa-nrpe-plugins
	 * @return string version du paquet
	 */
	public function getVersionPlugins()
	{
		return $this->version_plugin;
	}
	/**
	 * set la version du paquet gesa-nrpe-plugins
	 * @param string $version
	 */
	public function setVersionPlugins($version)
	{
		$this->version_plugin= $version;
	}
	/**
	 * retourne la version du paque gesa-web-interface
	 * @return string version du paquet
	 */
	public function getVersionWeb()
	{
		return $this->version_web;
	}
	/**
	 * set la version du paquet gesa-web-interface
	 * @param string $version
	 */
	public function setVersionWeb($version)
	{
		$this->version_web= $version;
	}
	/**
	 * retourne l'url du repository global
	 * @return string version du paquet
	 */
	public function getRepositoryGlobal()
	{
		return $this->repo_global;
	}
	/**
	 * set  l'url du repository global
	 * @param string $repo
	 */
	public function setRepositoryGlobal($repo)
	{
		$this->repo_global= $repo;
	}
	/**
	 * retourne l'url du repository GESA
	 * @return string version du paquet
	 */
	public function getRepositoryGESA()
	{
		return $this->repo_gesa;
	}
	/**
	 * set  l'url du repositiry GESA
	 * @param string $repo
	 */
	public function setRepositoryGESA($repo)
	{
		$this->repo_gesa= $repo;
	}
	/**
	 * retourne la date du dernier update
	 * @return string version du paquet
	 */
	public function getLastUpdate()
	{
		return $this->last_update;
	}
	/**
	 * set la date de dernière update
	 * @param string $date
	 */
	public function setLastUpdate($date)
	{
		$this->last_update= $date;
	}
	/**
	 * retourne le modele de la gesa
	 * @return string le modele de la gesa
	 */
	public function getModel()
	{
		return $this->model;
	}
	/**
	 * set le modele de la gesa
	 * @param string $model
	 */
	public function setModel($model)
	{
		$this->model = $model;
	}
	/**
	 * @brief set l'adresse ip local
	 * @param string $adresse : l'adresse ip locale de la gesa
	 */
	public function setLocalIPaddress($adresse)
	{
		$this->localip= $adresse;
	}
	/**
	 * @brief get l'adresse ip local
	 * @retval string l'adresse ip locale de la gesa
	 */
	public function getLocalIPaddress()
	{
		return $this->localip;
	}
	/**
	 * @brief set l'adresse ip publique
	 * @param string $adresse : l'adresse ip publique de la gesa
	 */
	public function setPublicIPaddress($adresse)
	{
		$this->publicip= $adresse;
	}
	/**
	 * @brief get l'adresse ip publique
	 * @retval string l'adresse ip publique de la gesa
	 */
	public function getPublicIPaddress()
	{
		return $this->publicip;
	}
	/**
	 * @brief set le masque de sous-réseau
	 * @param string $mask : le masque de sous-réseau
	 */
	public function setNetmask($mask)
	{
		$this->netmask = $mask;
	}
	/**
	 * @brief get le masque de sous-réseau
	 * @retval string le masque de sous-réseau
	 */
	public function getNetmask()
	{
		return $this->netmask;
	}
	/**
	 * @brief set la passerelle
	 * @param string $gateway : la passerelle
	 */
	public function setGateway($gateway)
	{
		$this->gateway = $gateway;
	}
	/**
	 * @brief get la passerelle
	 * @retval string la passerelle
	 */
	public function getGateway()
	{
		return $this->gateway;
	}
	/**
	 * @brief set le serveur DNS
	 * @param string $dns : le serveur DNS
	 */
	public function setDNS($dns)
	{
		if(is_array($dns))
		{
			$this->dns = $dns;
		}
		else
		{
			$this->dns = array($dns);
		}
	}
	/**
	 * @brief get le serveur DNS
	 * @retval string le serveur DNS
	 */
	public function getDNS()
	{
		return $this->dns;
	}
	/**
	 * @brief set l'url du serveur lié
	 * @param string $url : l'url du serveur lié
	 */
	public function setServerUrl($url)
	{
		$this->server_url = $url;
	}
	/**
	 * @brief get l'url du serveur lié
	 * @retval string l'url du serveur lié
	 */
	public function getServerUrl()
	{
		return $this->server_url;
	}

	public function check_ecatp($host,$command,$args="",$timeout=50,$accept_unknown=FALSE){
                if(empty($args))$args="";
                if(empty($timeout))$timeout=50;

		$host=$host->getIPAddress();
                $sn = $this->getSerialNumber();
		exec('/usr/local/esia/plugins/check_gesa -G '. $sn . ' -C '. $command. ' -t '.$timeout." -A '-H $host $args'",$output,$returnexec);

                if(empty($output[0]))  throw new GesaException("GESA UNREACHEABLE ".$host,0);
                if(!$accept_unknown && preg_match('#UNKNOWN\s+ERROR#',$output[0]) || $returnexec==3 ) throw new GesaException($output[0],1);
                if(preg_match("#NRPE: Command $command not defined#",$output[0])) throw new GesaException($output[0],2);

                //echo "<pre>".print_r($output,true)."</pre>";
                preg_match("#<(\w*)>#",end($output),$matches);
                if(empty($matches[1]))  return array("status"=>"CHECK",count($output),"data"=>$output);

                array_pop($output);

                $data=array();
                foreach($output as $key => $value){
                        $data[$key]=str_getcsv ( $value , ",", '"','"');
                }

                return array("status"=>$matches[1],"size"=>count($output),"data"=>$data);
        }


	/*@NAME: line_to_array
	 *@IN:	$headers	: Un array contenant les noms des colonnes
	*		$line 	 	: Un array contenant chaque champs d'une ligne
	*@OUT: Un tableau associatif
	*@TREAT: Utilise $headers pour nommer les keys de $line et retourner un tableau associatif de $line
	*@EXCEPTION:
	*/
	public static function line_to_array($headers, $line){
		$ret=array();
		for($i=0;$i < count($headers);++$i){
			if(isset($line[$i]))	$ret[ $headers[$i] ] = $line[$i];
			else $ret[ $headers[$i] ]= "";
		}
		return $ret;
	}
	/*@getInterfaces
	 *@IN: /
	*@OUT: Un tableau d'objet interface
	*@TREAT: retourne un tableau d'objet interface
	*@EXCEPTION: 	/
	*/
	public function getInterfaces()
	{
		return $this->interfaces;
	}
}

class GesaException extends Exception{}
?>
