// index.js

// Self called function to start on file include
(() => {
	document.addEventListener('DOMContentLoaded', () => {
		updateGesa();
	});
})();

function updateGesa()
{
	$('#updateGesa').on('click', async () => {
		const dialog = $('#dialog-info');
		const dialogParams = {
			resizable: true,
			draggable: true,
			width: 800,
			minHeight: 204,
			open: async (e, ui) => {
				try {
					await execWithLiveReturn('display.php?action=updateGesa', $('.console', dialog)[0]);

					const data = await ajaxPromiseJSON({
						url: 'display.php',
						data: { action: 'getGesaUpdateLog' },
					});

					$('.finish-msg .last_start', dialog).html(data.last_start);
					$('.finish-msg .last_end', dialog).html(data.last_end);
					$('.finish-msg .proc', dialog).html(data.log);
					$('.dialogContent', dialog).trigger('finished');
				} catch(err) {
					displayUserMessage(err, [], 'dialog-messages');

					// Change progress bar complete on failed
					$('#progressbar', dialog).addClass('failed');
					$('#progressbar', dialog).progressbar('value', $('#progressbar').progressbar('option', 'max'));
					$('#progressbar .progress-label', dialog).text(globals.lang.ERR_CANNOT_UPDATE);
					$('.start-msg', dialog).hide();
				}
			},
			close: () => {
				location.reload();
			},
		};

		openDialogByAJAX('dialog.php', { action: 'updateGesa' }, globals.lang['UPDATE'], dialog, dialogParams, {}, false);
	});
}

// Get server url & port and set it on html
async function getServerAsync(gesaSN)
{
	let server = { url: '', port: '' };

	const urlItem = $('.serverUrl');
	const portItem = $('.serverPort');
	urlItem.css('cursor', 'wait');
	portItem.css('cursor', 'wait');

	try {
		const data = await ajaxPromiseJSON({
			url: 'display.php',
			data: { action: 'getGesaServerInfos', gesa_sn: gesaSN },
		});

		server.url = data?.url || '/';
		server.port = data?.port || '/';
	
		urlItem.html(server.url);
		portItem.html(server.port);
	} catch(err) {
		urlItem.html('/');
		portItem.html('/');
		displayUserMessage(err);
	} finally {
		urlItem.css('cursor', '');
		portItem.css('cursor', '');

		return server;
	}
}

// Get public ip and set it on html
async function getIpPubAsync()
{
	const htmlItem = $('.publicIp');
	htmlItem.css('cursor', 'wait');

	try {
		const ipPub = await ajaxPromiseJSON({
			url: 'display.php',
			data: { action: 'getGesaIpPub' },
		});

		htmlItem.html(ipPub || '/');
	} catch(err) {
		htmlItem.html('/');
		displayUserMessage(err);
	} finally {
		htmlItem.css('cursor', '');
	}
}

// Get diag from ajax request & then set final html content (OK, FAILED) on progress bar
async function getProgressBarDiagAsync(htmlSelector, ajaxDataParam, ajaxOptParams={})
{
	// Init content
	const content = {
		class: 'EventCritical',
		text: globals.lang.FAILED,
	};

	try {
		const isOk = await ajaxPromiseJSON({
			url: 'display.php',
			data: ajaxDataParam,
			...ajaxOptParams,
		});

		if(isOk)
		{
			content.class = 'EventOK';
			content.text = globals.lang.OK;
		}
	} catch(err) {
		displayUserMessage(err);
	} finally {
		const htmlItem = $(htmlSelector);
		// Remove progress bar element
		$('.progressbar', htmlItem).progressbar('destroy');
		htmlItem.removeClass('progressBarTabCell');
		htmlItem.empty();
		// Set html content (OK or FAILED)
		htmlItem.addClass(content.class);
		htmlItem.html(content.text);
	}
}

// Get all data which may take some time to retreive and set them on the page when each request is over
async function getGesaAsyncData(gesaSN)
{
	// Init all progress bars
	const progressWrapper = $('.diagProgress');
	progressWrapper.addClass('progressBarTabCell');
	setProgressBar($('.progressbar', progressWrapper));

	// Start all requests symultaneously
	const serverPromise = getServerAsync(gesaSN);
	getIpPubAsync();
	// Get diag status DNS and set it on html
	getProgressBarDiagAsync('.diagDNS', { action: 'getGesaDiagDNS' });
	// Get diag status for WEB access and set it on html
	getProgressBarDiagAsync('.diagWEB', { action: 'getGesaDiagWEB' });
	// Get diag status ECATP client and set it on html
	getProgressBarDiagAsync('.diagECATP', { action: 'getGesaDiagECATP' });
	
	// Everything after await serverPromise will be executed after getServerAsync() response (and timeout)
	const server = await serverPromise;
	// Get diag status server connection and set it on html
	getProgressBarDiagAsync('.diagSRV', { action: 'getGesaDiagSRV', server_url: server.url, port: server.port });
}
