// protocols.js

// Self called function to start on file include
(() => {
	document.addEventListener("DOMContentLoaded", () => {
		createTabsPersistant('tabs-protocols-conf');
	});
})();

// Init function on SSH tab load
function initTabSSH(filesDir)
{
	setFormClientValidation('#addConfFile-ssh');
	copyEltTextOnClick($('.sshConf .cell-filename'), 'span', globals.lang.ERR_COPY_FILE_PATH, filesDir);
	addProtocolConfigFile('addConfFile-ssh');
	delProtocolConfigFile($('.deleteFileSSH'));
	setModifyConfSSH($('.modifyFileSSH'));
}

// Init function for ssh keys on SSH tab load
function initTabSSHKeys()
{
	copyEltTextOnClick($('.sshKeys .cell-pubkey'), 'span', globals.lang.ERR_COPY_FILE_PATH);
}

// Init function on powershell tab load
function initTabPW(filesDir)
{
	setFormClientValidation('#addConfFile-powershell');
	copyEltTextOnClick($('.cell-filename'), 'span', globals.lang.ERR_COPY_FILE_PATH, filesDir);
	addProtocolConfigFile('addConfFile-powershell');
	delProtocolConfigFile($('.deleteFilePW'));
	setModifyConfPW($('.modifyFilePW'));
}

// Init function on ipmi tab load
function initTabIPMI(filesDir)
{
	setSelect('#selectPriv-ipmi');
	setSelect('#selectDriver-ipmi');
	setFormClientValidation('#addConfFile-ipmi');
	copyEltTextOnClick($('.cell-filename'), 'span', globals.lang.ERR_COPY_FILE_PATH, filesDir);
	addProtocolConfigFile('addConfFile-ipmi');
	delProtocolConfigFile($('.deleteFileIPMI'));
	setModifyConfIPMI($('.modifyFileIPMI'));
}

// Init function on virtualisation tab load
function initTabVirt(filesDir)
{
	setFormClientValidation('#addConfFile-virt');
	copyEltTextOnClick($('.cell-filename'), 'span', globals.lang.ERR_COPY_FILE_PATH, filesDir);
	addProtocolConfigFile('addConfFile-virt');
	delProtocolConfigFile($('.deleteFileVirt'));
	setModifyConfVirt($('.modifyFileVirt'));
}

// Init function on backup tab load
function initTabBck(filesDir, subtab)
{
	const formSelector = 'addConfFile-backup-' + subtab;
	setFormClientValidation('#' + formSelector);
	copyEltTextOnClick($('.cell-filename', '#' + formSelector), 'span', globals.lang.ERR_COPY_FILE_PATH, filesDir);
	addProtocolConfigFile(formSelector);
	delProtocolConfigFile($('.deleteFileBackup', '#' + formSelector));
	setModifyConfBck($('.modifyFileBackup', '#' + formSelector), subtab);
}

// Add protocol config file
function addProtocolConfigFile(formSelector)
{
	$('#' + formSelector).on('submit', async e => {
		e.preventDefault();

		try {
			const formData = getFormValues(formSelector);

			await ajaxPromiseJSON({
				url: 'display.php',
				data: {
					action: 'addProtocolConfFile',
					...formData,
				},
			});

			reloadActiveTab($('#tabs-protocols-conf'));
		} catch (err) {
			displayUserMessage(err);
		}
	});
}

// Delete protocol config file
function delProtocolConfigFile(delButtons)
{
	delButtons.on('click', async function() {
		try {
			await ajaxPromiseJSON({
				url: 'display.php',
				data: {
					action: 'delProtocolConfFile',
					fileName: $(this).attr('data-name'),
				},
			});

			reloadActiveTab($('#tabs-protocols-conf'));
		} catch (err) {
			displayUserMessage(err);
		}
    });
}

// Update protocol config file
function updProtocolConfigFile(updButton, fileName)
{
	updButton.on('click', async function() {
		const row = $(this).closest('tr');
		// Get all inputs values
		let values = {};
		$('input, select', row).each(function()
		{
			values[$(this).attr('name')] = $(this).val();
		});

		try {
			await ajaxPromiseJSON({
				url: 'display.php',
				data: {
					action: 'updProtocolConfFile',
					tab: $(this).closest('form').find('input[name="tab"]').val(),
					subtab: $(this).closest('form').find('input[name="subtab"]').val() || '',
					fileName,
					...values,
				},
			});

			reloadActiveTab($('#tabs-protocols-conf'));
		} catch (err) {
			displayUserMessage(err);
		}
    });
}

// Common protocols transforms row cells for user config modification
function setModifyConfCommon(row, cells, fileName, customSelectElts=[])
{
	const table = row.closest('table');

	// Hide every span inside cells which will be transformed in input
	Object.values(cells).forEach(cell => {
		$('span', cell).hide();
	});

	// Disable other rows actions
	$('.cell-actions button', table).attr('disabled', true);
	$('tfoot input', table).attr('disabled', true);

	// Modify actions list on table row when passing in update mode
	$('.cell-actions > *', row).hide();
	$('.cell-actions', row).append(
		'<button type="button" class="btnIcon btnValid" title="' + globals.lang.VALIDATE + '"></button>' +
		'<button type="button" class="btnIcon btnRefuse" title="' + globals.lang.CANCEL + '"></button>'
	);
	// Set new actions valid & cancel
	updProtocolConfigFile($('.cell-actions .btnValid', row), fileName);
	$('.cell-actions .btnRefuse', row).on('click', function() {
		// Destroy slim select elements
		customSelectElts.forEach(customSelect => { customSelect.destroy() });
		// Show initial cells content
		Object.values(cells).forEach(cell => {
			// Remove cell input
			$('input', cell).remove();
			// Remove cell select
			$('select', cell).remove();
			// Show initial cell content
			$('span', cell).show();
		});
		// Show initial cell actions content
		$('.btnValid', row).remove();
		$('.btnRefuse', row).remove();
		$('.cell-actions > *', row).show();
		// Enable other rows actions
		$('.cell-actions button', table).attr('disabled', false);
		$('tfoot input', table).attr('disabled', false);
	});
}

// Transform row cells for user config modification on ssh config file
function setModifyConfSSH(updButtons)
{
	updButtons.on('click', function() {
		const row = $(this).closest('tr');
		const cells = {
			host: $('.cell-host', row),
			port: $('.cell-port', row),
			user: $('.cell-user', row),
			passwd: $('.cell-passwd', row),
		};
		const values = {
			host: $('span', cells.host).html(),
			port: $('span', cells.port).html(),
			user: $('span', cells.user).html(),
		};

		setModifyConfCommon(row, cells, $(this).attr('data-name'));

		// Create row update inputs
		cells.host.append('<input type="text" name="host" value="' + values.host + '">');
		cells.port.append('<input type="number" name="port" min="0" max="65535" value="' + values.port + '">');
		cells.user.append('<input type="text" name="user" value="' + values.user + '">');
		cells.passwd.append('<input type="password" name="password" value="">');
    });
}

// Transform row cells for user config modification on powershell config file
function setModifyConfPW(updButtons)
{
	updButtons.on('click', function() {
		const row = $(this).closest('tr');
		const cells = {
			host: $('.cell-host', row),
			user: $('.cell-user', row),
			passwd: $('.cell-passwd', row),
		};
		const values = {
			host: $('span', cells.host).html(),
			user: $('span', cells.user).html(),
		};

		setModifyConfCommon(row, cells, $(this).attr('data-name'));

		// Create row update inputs
		cells.host.append('<input type="text" name="host" value="' + values.host + '">');
		cells.user.append('<input type="text" name="user" value="' + values.user + '">');
		cells.passwd.append('<input type="password" name="password" value="">');
    });
}

// Transform row cells for user config modification on ipmi config file
function setModifyConfIPMI(updButtons)
{
	updButtons.on('click', async function() {
		const row = $(this).closest('tr');
		const cells = {
			user: $('.cell-user', row),
			passwd: $('.cell-passwd', row),
			priv: $('.cell-priv', row),
			driver: $('.cell-driver', row),
		};
		const values = {
			user: $('span', cells.user).html(),
			priv: $('span', cells.priv).html(),
			driver: $('span', cells.driver).html(),
		};

		// Create row update inputs
		cells.user.append('<input type="text" name="user" value="' + values.user + '">');
		cells.passwd.append('<input type="password" name="password" value="">');
		// Privilege select
		let privSelect = $('#selectPriv-ipmi').clone();
		privSelect.attr('id', 'selectPriv-ipmi-upd');
		privSelect.val(values.priv);
		privSelect.show();
		cells.priv.append(privSelect);
		let privSelectElt = setSelect('#selectPriv-ipmi-upd');
		// Driver select
		let driverSelect = $('#selectDriver-ipmi').clone();
		driverSelect.attr('id', 'selectDriver-ipmi-upd');
		driverSelect.find('option').each(function()
		{
			// Set selected option by option text instead of value
			if($(this).text() == values.driver)
			{
				$(this).prop('selected', true);
				// Break each loop
				return false;
			}
		});
		driverSelect.show();
		cells.driver.append(driverSelect);
		let driverSelectElt = setSelect('#selectDriver-ipmi-upd');

		setModifyConfCommon(row, cells, $(this).attr('data-name'), [privSelectElt, driverSelectElt]);
    });
}

// Transform row cells for user config modification on virtualization config file
function setModifyConfVirt(updButtons)
{
	updButtons.on('click', function() {
		const row = $(this).closest('tr');
		const cells = {
			user: $('.cell-user', row),
			passwd: $('.cell-passwd', row),
		};
		const values = {
			user: $('span', cells.user).html(),
		};

		setModifyConfCommon(row, cells, $(this).attr('data-name'));

		// Create row update inputs
		cells.user.append('<input type="text" name="login" value="' + values.user + '">');
		cells.passwd.append('<input type="password" name="password" value="">');
    });
}

// Transform row cells for user config modification on backup config file
function setModifyConfBck(updButtons, type)
{
	if(type == 'appassure')
	{
		updButtons.on('click', function() {
			const row = $(this).closest('tr');
			const cells = {
				community: $('.cell-community', row),
				port: $('.cell-port', row),
			};
			const values = {
				community: $('span', cells.community).html(),
				port: $('span', cells.port).html(),
			};

			setModifyConfCommon(row, cells, $(this).attr('data-name'));

			// Create row update inputs
			cells.community.append('<input type="text" name="community" value="' + values.community + '">');
			cells.port.append('<input type="number" name="port" value="' + values.port + '" min="0" max="65535">');
		});
	}
	else if(type == 'bareos')
	{
		updButtons.on('click', function() {
			const row = $(this).closest('tr');
			const cells = {
				passwd: $('.cell-passwd', row),
			};

			setModifyConfCommon(row, cells, $(this).attr('data-name'));

			// Create row update inputs
			cells.passwd.append('<input type="password" name="pass" value="">');
		});
	}
	else if(type == 'proxmox')
	{
		updButtons.on('click', function() {
			const row = $(this).closest('tr');
			const cells = {
				url: $('.cell-url', row),
				username: $('.cell-username', row),
				tokenname: $('.cell-token-name', row),
				tokenval: $('.cell-token-val', row),
			};
			const values = {
				url: $('span', cells.url).html(),
				username: $('span', cells.username).html(),
				tokenname: $('span', cells.tokenname).html(),
			};

			setModifyConfCommon(row, cells, $(this).attr('data-name'));

			// Create row update inputs
			cells.url.append('<input type="url" name="url" value="' + values.url + '" pattern="https://.*:.*">');
			cells.username.append('<input type="text" name="username" value="' + values.username + '" pattern=".*@.*">');
			cells.tokenname.append('<input type="text" name="token_name" value="' + values.tokenname + '">');
			cells.tokenval.append('<input type="password" name="token_value" value="">');
		});
	}
	else if(type == 'veeam')
	{
		updButtons.on('click', function() {
			const row = $(this).closest('tr');
			const cells = {
				port: $('.cell-port', row),
				dbname: $('.cell-dbname', row),
				dbuser: $('.cell-dbuser', row),
				dbpass: $('.cell-dbpass', row),
			};
			const values = {
				port: $('span', cells.port).html(),
				dbname: $('span', cells.dbname).html(),
				dbuser: $('span', cells.dbuser).html(),
			};

			setModifyConfCommon(row, cells, $(this).attr('data-name'));

			// Create row update inputs
			cells.port.append('<input type="number" name="port" value="' + values.port + '" min="0" max="65535">');
			cells.dbname.append('<input type="text" name="dbname" value="' + values.dbname + '">');
			cells.dbuser.append('<input type="text" name="dbuser" value="' + values.dbuser + '">');
			cells.dbpass.append('<input type="password" name="dbpass" value="">');
		});
	}
	else if(type == 'veeam365')
	{
		updButtons.on('click', function() {
			const row = $(this).closest('tr');
			const cells = {
				url: $('.cell-url', row),
				proxyserver: $('.cell-proxyserver', row),
				username: $('.cell-username', row),
				password: $('.cell-password', row),
			};
			const values = {
				url: $('span', cells.url).html(),
				proxyserver: $('span', cells.proxyserver).html(),
				username: $('span', cells.username).html(),
			};

			setModifyConfCommon(row, cells, $(this).attr('data-name'));

			// Create row update inputs
			cells.url.append('<input type="url" name="url" value="' + values.url + '" pattern="https://.*:.*">');
			cells.proxyserver.append('<input type="text" name="proxyserver" value="' + values.proxyserver + '">');
			cells.username.append('<input type="text" name="username" value="' + values.username + '">');
			cells.password.append('<input type="password" name="password" value="">');
		});
	}
}
